<?php

namespace Litecms\Building\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Litecms\Building\Actions\BuildingAction;
use Litecms\Building\Http\Requests\BuildingActionRequest;
use Litecms\Building\Http\Resources\BuildingResource;
use Litecms\Building\Models\Building;

/**
 * Admin web controller class.
 */
class BuildingActionController extends BaseController
{

    /**
     * Action controller function for building.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(BuildingActionRequest $request, Building $building, $action)
    {
        try {
            $request = $request->all();
            $building = BuildingAction::run($action, $building, $request);

            $data = new BuildingResource($building);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('building::building.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('building/building/' . $building->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('building/building/' . $building->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
