<?php

namespace Litecms\Building\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Exception;
use Litecms\Building\Http\Requests\BuildingActionsRequest;
use Litecms\Building\Actions\BuildingActions;

/**
 * Admin web controller class.
 */
class BuildingActionsController extends BaseController
{

    /**
     * Action controller function for building.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(BuildingActionsRequest $request, $action)
    {
        try {
            $building = BuildingActions::run($request, $action);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('building::building.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('building/building/' . $action))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('building/building/' . $action))
                ->redirect();
        }
    }
}
