<?php

namespace Litecms\Building\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Illuminate\Support\Str;
use Litecms\Building\Actions\BuildingExim;
use Litecms\Building\Http\Requests\BuildingEximRequest;

/**
 * Admin web controller class.
 */
class BuildingEximController extends BaseController
{
    /**
     * Action controller function for building.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(BuildingEximRequest $request, $exim)
    {
        try {
            $function = Str::camel($exim);
            $data = BuildingExim::$function($request);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('building:building.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('building/building/' . $exim))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('building/building/' . $exim))
                ->redirect();
        }
    }
}
