<?php
namespace Litecms\Building\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Litecms\Building\Events\BuildingAction as BuildingActionEvent;
use Litecms\Building\Models\Building;

class BuildingAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $building;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param BuildingActionEvent $building
     */
    public function __construct(BuildingActionEvent $building)
    {
        $this->action = $event->action;
        $this->building = $building;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Building Approved - ' . config('app.name'))
            ->view('building::building.email.action', ['data' => $this->building]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
